@@ -1,9 +1,8 @@
 #' Locator for ggplots.
 #'
-#' Locator for ggplots.
+#' Locator for ggplots. (Note : only accurate when extent = "normal" when using ggmap.)
 #' 
 #' @param n number of points to locate.
-#' @param object plot to locate on
 #' @param message turn messaging from grid.ls on/off
 #' @param xexpand expand argument in scale_x_continuous
 #' @param yexpand expand argument in scale_y_continuous
@@ -14,11 +13,12 @@
 #' 
 #' 
 #' \dontrun{
-#' df <- data.frame(xvar = 1:10, yvar = 1:10)
-#' qplot(xvar, yvar, data = df) + annotate(geom = 'point', x = 3, y = 6)
-#' gglocator(4)
+#' df <- expand.grid(x = 0:-5, y = 0:-5)
+#' (p <- qplot(x, y, data = df) + 
+#'   annotate(geom = 'point', x = -2, y = -2, colour = 'red'))
+#' gglocator() 
 #' 
-#' qplot(xvar, yvar, data = df) + 
+#' p + 
 #'   scale_x_continuous(expand = c(0,0)) + 
 #'   scale_y_continuous(expand = c(0,0))
 #' gglocator(1, xexpand = c(0,0), yexpand = c(0,0))
@@ -26,28 +26,36 @@
 #' }
 #' 
 #'   
-gglocator <- function(n = 1, object = last_plot(), message = FALSE, xexpand = c(.05,0), yexpand = c(.05, 0)){
+gglocator <- function(n = 1, message = FALSE, 
+  xexpand = c(.05, 0), yexpand = c(.05, 0)
+){
   
   if(n > 1){
     df <- NULL
     for(k in 1:n){
-      df <- rbind(df, gglocator(object = object, message = message, 
+      df <- rbind(df, gglocator(message = message, 
         xexpand = xexpand, yexpand = yexpand))
     }
     return(df)
   }
   
-  x <- grid.ls(print = message)[[1]]
-  x <- x[ grep("panel-", grid.ls(print=message)[[1]]) ] #locate the panel
-  seekViewport(x)
+  # find the correct viewport for the npc coordinates
+  x <- grid.ls(print = message)$name
+  x <- x[grep("panel.", x)][1] 
+  seekViewport(x)  
+  
+  # get the position relative to that viewport
   loc <-  as.numeric(grid.locator("npc"))
 
+  # scale the position to the plot
+  object <- last_plot()
   xrng <- with(object, range(data[,deparse(mapping$x)]))
   yrng <- with(object, range(data[,deparse(mapping$y)]))    
     
   xrng <- scales::expand_range(range = xrng, mul = xexpand[1], add = xexpand[2])
   yrng <- scales::expand_range(range = yrng, mul = yexpand[1], add = yexpand[2])    
 
+  # format and return
   point <- data.frame(xrng[1] + loc[1]*diff(xrng), yrng[1] + loc[2]*diff(yrng))
   names(point) <- with(object, c(deparse(mapping$x), deparse(mapping$y)))
   point
